Timer

Struct Timer 

pub struct Timer<T: TimerInterface> { /* private fields */ }
Generic timer object allowing blocking wait and interrupt enablement.

Implementations

Source

impl<T: TimerInterface> Timer<T>

pub fn new(timer: T) -> Self

Creates new instance.

pub fn enable(&mut self)

Enables timer.

pub fn wait(&self, duration: Duration)

Blocking waits for a duration or maximal possible timer. The timer must be enabled before calling wait.