Memory mapped timer driver implementations.
See I5.6 Generic Timer memory-mapped registers overview.
Structs
- CntAcr
- Counter-timer Access Control Register.
- CntBase
- Table I2-4 CNTBaseN memory map
- CntControl
Base - Table I2-1 CNTControlBase memory map
- CntCr
- Counter Control Register
- CntCtl
Base - Table I2-3 CNTCTLBase memory map
- CntEl0
Acr - Counter-timer EL0 Access Control Register.
- CntEl0
Base - CntEl0Base frame is identical to the CntBase frame, except that CNTVOFF, CNTEL0ACR registers are never visible and CNTEL0ACR of the corresponding CntBase controls the access of the physical and virtual timer registers.
- CntId
- Counter Identification Register.
- CntRead
Base - Table I2-2 CNTReadBase memory map
- CntSr
- Counter Status Register
- Features
- Timer feature bits, defined at I5.7.16 CNTTIDR, Counter-timer Timer ID Register description.
- Generic
Timer Cnt - Driver for the CNTBase timer block.
- Generic
Timer CntEl0 - Driver for the CNTEL0Base timer block.
- Generic
Timer Control - Driver for the CNTControlBase block.
- Generic
Timer Ctl - Driver for the CNTCTLBase block.
- Mmio
Timer TimerInterfaceimplementation of the MMIO based physical or virtual timer instance of the CNTBase block.- Timer
Control - Common control register of the physical and virtual timers. Defined at I5.7.10 CNTP_CTL, Counter-timer Physical Timer Control and at CNTV_CTL, Counter-timer Virtual Timer Control.
- Timer
Regs - Repeated subset of register that describe a physical or virtual timer in the CntBase or CntEl0Base blocks.